@@ -84,7 +84,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
